@@ -668,10 +668,8 @@ typedef struct {
 } BroadbandMenuItemInfo;
 
 static void
-menu_item_info_destroy (gpointer data, GClosure *closure)
+menu_item_info_destroy (BroadbandMenuItemInfo *info)
 {
-	BroadbandMenuItemInfo *info = data;
-
 	g_object_unref (G_OBJECT (info->device));
 	if (info->connection)
 		g_object_unref (info->connection);
@@ -700,7 +698,7 @@ add_connection_item (NMDevice *device,
 
 	info = g_slice_new0 (BroadbandMenuItemInfo);
 	info->applet = applet;
-	info->device = g_object_ref (device);
+	info->device = g_object_ref (G_OBJECT (device));
 	info->connection = connection ? g_object_ref (connection) : NULL;
 
 	g_signal_connect_data (item, "activate",
@@ -709,6 +707,7 @@ add_connection_item (NMDevice *device,
 	                       (GClosureNotify) menu_item_info_destroy, 0);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
 }
 
 static void
@@ -784,6 +783,7 @@ add_menu_item (NMDevice *device,
 		                            applet);
 		gtk_widget_set_sensitive (GTK_WIDGET (item), FALSE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		gtk_widget_show (item);
 	}
 
 	/* Add the default / inactive connection items */
