@@ -113,20 +113,20 @@ bt_get_icon (NMDevice *device,
 
 	switch (state) {
 	case NM_DEVICE_STATE_PREPARE:
-		*tip = g_strdup_printf (_("Preparing mobile broadband connection '%s'..."), id);
+		*tip = g_strdup_printf (_("Preparing mobile broadband connection “%s”…"), id);
 		break;
 	case NM_DEVICE_STATE_CONFIG:
-		*tip = g_strdup_printf (_("Configuring mobile broadband connection '%s'..."), id);
+		*tip = g_strdup_printf (_("Configuring mobile broadband connection “%s”…"), id);
 		break;
 	case NM_DEVICE_STATE_NEED_AUTH:
-		*tip = g_strdup_printf (_("User authentication required for mobile broadband connection '%s'..."), id);
+		*tip = g_strdup_printf (_("User authentication required for mobile broadband connection “%s”…"), id);
 		break;
 	case NM_DEVICE_STATE_IP_CONFIG:
-		*tip = g_strdup_printf (_("Requesting a network address for '%s'..."), id);
+		*tip = g_strdup_printf (_("Requesting a network address for “%s”…"), id);
 		break;
 	case NM_DEVICE_STATE_ACTIVATED:
 		*out_icon_name = "nm-device-wwan";
-		*tip = g_strdup_printf (_("Mobile broadband connection '%s' active"), id);
+		*tip = g_strdup_printf (_("Mobile broadband connection “%s” active"), id);
 		break;
 	default:
 		break;
