@@ -31,7 +31,7 @@ void applet_info_dialog_show (NMApplet *applet);
 
 void applet_about_dialog_show (NMApplet *applet);
 
-GtkWidget *applet_warning_dialog_show (const char *message);
+GtkWidget *applet_missing_ui_warning_dialog_show (void);
 
 GtkWidget *applet_mobile_password_dialog_new (NMConnection *connection,
                                               GtkEntry **out_secret_entry);
