@@ -559,7 +559,8 @@ addr_delete_clicked (GtkButton *button, gpointer user_data)
 	if (gtk_tree_model_get_iter (model, &iter, (GtkTreePath *) selected_rows->data))
 		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 
-	g_list_free_full (selected_rows, (GDestroyNotify) gtk_tree_path_free);
+	g_list_foreach (selected_rows, (GFunc) gtk_tree_path_free, NULL);
+	g_list_free (selected_rows);
 
 	num_rows = gtk_tree_model_iter_n_children (model, NULL);
 	if (num_rows && gtk_tree_model_iter_nth_child (model, &iter, NULL, num_rows - 1)) {
@@ -923,9 +924,9 @@ key_pressed_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 }
 
 static void
-address_line_info_destroy (gpointer data, GClosure *closure)
+address_line_info_destroy (AddressLineInfo *info)
 {
-	g_slice_free (AddressLineInfo, data);
+	g_slice_free (AddressLineInfo, info);
 }
 
 static void
@@ -971,7 +972,7 @@ cell_editing_started (GtkCellRenderer *cell,
 	g_signal_connect_data (G_OBJECT (editable), "changed",
 	                       (GCallback) cell_changed_cb,
 	                       info,
-	                       address_line_info_destroy, 0);
+	                       (GClosureNotify) address_line_info_destroy, 0);
 
 	/* Set up key pressed handler - need to handle Tab key */
 	g_signal_connect (G_OBJECT (editable), "key-press-event",
@@ -1302,7 +1303,7 @@ ui_to_setting (CEPageIP4 *self, GError **error)
 	model = gtk_tree_view_get_model (priv->addr_list);
 	iter_valid = gtk_tree_model_get_iter_first (model, &tree_iter);
 
-	addresses = g_ptr_array_new_with_free_func (free_one_addr);
+	addresses = g_ptr_array_sized_new (1);
 	while (iter_valid) {
 		char *addr = NULL, *netmask = NULL, *addr_gw = NULL;
 		NMIPAddress *nm_addr;
@@ -1427,8 +1428,10 @@ ui_to_setting (CEPageIP4 *self, GError **error)
 	valid = TRUE;
 
 out:
-	if (addresses)
+	if (addresses) {
+		g_ptr_array_foreach (addresses, (GFunc) free_one_addr, NULL);
 		g_ptr_array_free (addresses, TRUE);
+	}
 	g_free (gateway);
 
 	g_strfreev (dns_servers);
