@@ -87,6 +87,8 @@ static const char *known_8021x_props[] = {
 	NM_SETTING_802_1X_PHASE2_PRIVATE_KEY,
 	NM_SETTING_802_1X_PHASE2_PRIVATE_KEY_PASSWORD,
 	NM_SETTING_802_1X_PHASE2_PRIVATE_KEY_PASSWORD_FLAGS,
+	NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH,
+	NM_SETTING_802_1X_PHASE2_DOMAIN_SUFFIX_MATCH,
 	NULL
 };
 
