@@ -19,11 +19,6 @@
  * (C) Copyright 2007 - 2012 Red Hat, Inc.
  */
 
-
-/* WARNING: this file is private API between nm-applet and various GNOME
- * bits; it may change without notice and is not guaranteed to be stable.
- */
-
 #ifndef NMA_WIRELESS_DIALOG_H
 #define NMA_WIRELESS_DIALOG_H
 
@@ -52,10 +47,6 @@ typedef struct {
 	GObjectClass parent;
 } NMAWirelessDialogClass;
 
-#if !GLIB_CHECK_VERSION(2,31,0)
-#define GLIB_DEPRECATED_FOR(x)
-#endif
-
 GLIB_DEPRECATED_FOR(nma_wifi_dialog_get_type)
 GType nma_wireless_dialog_get_type (void);
 
@@ -80,14 +71,5 @@ NMConnection * nma_wireless_dialog_get_connection (NMAWirelessDialog *dialog,
                                                    NMDevice **device,
                                                    NMAccessPoint **ap);
 
-GLIB_DEPRECATED_FOR(nma_wifi_dialog_nag_user)
-GtkWidget * nma_wireless_dialog_nag_user (NMAWirelessDialog *dialog);
-
-GLIB_DEPRECATED_FOR(nma_wifi_dialog_set_nag_ignored)
-void nma_wireless_dialog_set_nag_ignored (NMAWirelessDialog *dialog, gboolean ignored);
-
-GLIB_DEPRECATED_FOR(nma_wifi_dialog_get_nag_ignored)
-gboolean nma_wireless_dialog_get_nag_ignored (NMAWirelessDialog *dialog);
-
 #endif	/* NMA_WIRELESS_DIALOG_H */
 
